@@ -15,7 +15,8 @@ from django.views import generic
 
 from chance.forms import (RegistrationForm, TalkSubmissionForm,
                             TransactionConfirmForm)
-from chance.models import Event, Registration, Talk, Transaction
+from chance.models import (Event, Registration, Talk, Transaction, Track,
+                           ScheduleItem)
 
 
 
@@ -290,3 +291,10 @@ class TransactionNotifyView(generic.View):
             return HttpResponseBadRequest('Error getting transaction details')
         return HttpResponse('k thanks bye!')
 
+class ScheduleView(EventMixin, generic.ListView):
+    model = ScheduleItem
+
+    def get_queryset(self):
+        return ScheduleItem.objects.filter(track__in=self.event.tracks.all(),
+                start__isnull=False, end__isnull=False)
+
